/*
 * Awake File: Easy file upload & download through HTTP with Java
 * Awake SQL: Remote JDBC access through HTTP.                                    
 * Copyright (C) 2011, Kawan Softwares S.A.S.
 * (http://www.awakeframework.org). All rights reserved.                                
 *                                                                               
 * Awake File/SQL is free software; you can redistribute it and/or                 
 * modify it under the terms of the GNU Lesser General Public                    
 * License as published by the Free Software Foundation; either                  
 * version 2.1 of the License, or (at your option) any later version.            
 *                                                                               
 * Awake File/SQL is distributed in the hope that it will be useful,               
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             
 * Lesser General Public License for more details.                               
 *                                                                               
 * You should have received a copy of the GNU Lesser General Public              
 * License along with this library; if not, write to the Free Software           
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  
 * 02110-1301  USA
 *
 * Any modifications to this file must keep this entire header
 * intact.
 */

// Copyright (c) Kawan Softwares S.A.S, 2011
//
// Last Updates: 
// 09/08/05 16:35 NDP - add isPossibleWindowFilename()
// 10/10/05 11:15 NDP - Add ACTION_REGISTER_BEGIN in StringUtil
// 10/10/05 11:15 NDP - 0.9.8 - Add ACTION_KEY_SEARCH in StringUtil
// 12/10/05 17:25 NDP - 0.9.8 - Suppress Parms.IS_LOCALHOST
// 14/10/05 17:25 NDP - 0.9.8 - Add ACTION_DELETE_SERVER_KEY
// 17/10/05 20:25 NDP - 0.9.8 - Add openBrowserForAction() & move them to Urlutil
// 09/11/05 14:55 NDP - changeKeyVersion : Add Convert the Cryptix Version String to us!
// 24/11/05 15:55 NDP - Comments
// 02/11/05 20:25 NDP - prevent infinite loop in changeKeyVersion() & nex text
// 21/12/05 17:15 NDP - Add loadDebugFile()
// 23/12/05 19:45 NDP - Add getDisplayName()
// 03/06/05 16:00 NDP - Add wordWrap()
// 06/06/06 18:40 NDP - Auto Line Return Support preference value in wordWrap()
// 04/08/06 18:05 NDP - Add new cut() function for string to be passed to sql
// 06/12/06 10:46 ABE - Add getHashMD5
// 05/01/10 16:05 NDP - Add List<String> toBase64(List<String> list) & Verify all input parameters
// 27/09/10 20:10 NDP - No more  fromBase64/toBase64 on lists

package org.awakefw.file.util;

import org.awakefw.file.api.util.Base64;

/**
 * Misc utilites Strings
 * 
 * @author Nicolas de Pomereu
 * 
 */
public class StringUtil {
    /** The debug flag */
    public boolean DEBUG = false;

    /** Universal and clean line separator */
    public static String CR_LF = System.getProperty("line.separator");

    /**
     * Convert a String to a Base64 String
     * 
     * @param s
     *            the String to convert
     * @return The converted String converted in Base64
     */
    public static String toBase64(String s) {
	if (s == null) {
	    throw new IllegalArgumentException("input string can not be null!");
	}

	return Base64.byteArrayToBase64(s.getBytes());
    }

    /**
     * return a "" empty string if null or a trimed stgring if not null
     * 
     * @param action
     *            the input string
     * @return the empty stgring or trimed string
     */
    public static String getTrimValue(String string) {
	if (string == null) {
	    return "";
	} else {
	    return string.trim();
	}
    }
    
    /**
     * Convert a String to a Base64 String
     * 
     * @param s
     *            the String to convert
     * @return The converted String converted in Base64
     */
    public static String fromBase64(String s) {
	if (s == null) {
	    throw new IllegalArgumentException("input string can not be null!");
	}

	return new String(Base64.base64ToByteArray(s));
    }

    /**
     * Cut the String to 64 chars max
     * 
     * @param in
     *            the string to cut
     * @param maxLength
     *            the string max length
     * @return the cut string at maxLength chars
     */
    public static String cut(String in, int maxLength) {
	if (in == null) {
	    return null;
	}

	if (in.length() <= maxLength) {
	    return in;
	}

	// Ok, cut it to maxLength chars!
	return in.substring(0, maxLength);

    }

    /*
     * Cut the String to 64 chars max
     * 
     * @param in the string to cut
     * 
     * @return the cut string at 64chars
     */
    public static String cut64(String in) {
	if (in == null) {
	    return null;
	}

	if (in.length() <= 64) {
	    return in;
	}

	// Ok, cut it to 64 chars!
	return in.substring(0, 64);

    }

    /**
     * Return true if the filename is a Window possible Filename
     * 
     * @param filename
     *            the filename to test
     * @return true if the filename is a Window Filename
     */
    public static boolean isPossibleWindowFilename(String filename) {
	if (filename == null) {
	    throw new IllegalArgumentException(
		    "input filename can not be null!");
	}

	if (filename.indexOf("\\") != -1 || filename.indexOf("/") != -1
		|| filename.indexOf(":") != -1 || filename.indexOf("*") != -1
		|| filename.indexOf("?") != -1 || filename.indexOf("\"") != -1
		|| filename.indexOf("\"") != -1 || filename.indexOf("<") != -1
		|| filename.indexOf(">") != -1 || filename.indexOf("|") != -1) {
	    return false;
	} else {
	    return true;
	}
    }

    /**
     * debug tool
     */
    @SuppressWarnings("unused")
    private static void debug(String s) {
	if (new StringUtil().DEBUG) {
	    AwakeLogger.log(s);
	}
    }

}
